==> claromentis-framework-9.6.6-26891208.zip: web/intranet/infocapture/classes/Event/SaveSlaRuleEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
class SaveSlaRuleEvent extends Event implements ProjectEventInterface
{
    protected $project;
    protected $fields_rule_id;
    protected $fields_rule_name;
    protected $timer_type;
    protected $old_rules;
    protected $new_rules;
    public function __construct(\HDProject $project, int $_e7abfa820a3de22659425ae05962f998, string $_d6ae4fd435b96c98064a7e6e29911624, int $_c81931b478b71965c9977c8cbb5f8da4, array $_bf4b599ba97e569860bd6ef9aea99c33, array $_af3a0d50187ba59bd7cde5c4c5bb8520)
    {
        $this->project = $project;
        $this->fields_rule_id = $_e7abfa820a3de22659425ae05962f998;
        $this->fields_rule_name = $_d6ae4fd435b96c98064a7e6e29911624;
        $this->timer_type = $_c81931b478b71965c9977c8cbb5f8da4;
        $this->old_rules = $_bf4b599ba97e569860bd6ef9aea99c33;
        $this->new_rules = $_af3a0d50187ba59bd7cde5c4c5bb8520;
    }
    
    
    
    
    public function getProject() : \HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getFieldsRuleId() : int
    {
        return $this->fields_rule_id;
    }
    
    
    
    
    public function getFieldsRuleName() : string
    {
        return $this->fields_rule_name;
    }
    
    
    
    
    public function getTimerType() : int
    {
        return $this->timer_type;
    }
    
    
    
    
    public function getOldRules()
    {
        return $this->old_rules;
    }
    
    
    
    
    public function getNewRules()
    {
        return $this->new_rules;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/infocapture/classes/Event/SaveSlaRuleEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
class SaveSlaRuleEvent extends Event implements ProjectEventInterface
{
    protected $project;
    protected $fields_rule_id;
    protected $fields_rule_name;
    protected $timer_type;
    protected $old_rules;
    protected $new_rules;
    public function __construct(\HDProject $project, int $_e7abfa820a3de22659425ae05962f998, string $_d6ae4fd435b96c98064a7e6e29911624, int $_c81931b478b71965c9977c8cbb5f8da4, array $_bf4b599ba97e569860bd6ef9aea99c33, array $_af3a0d50187ba59bd7cde5c4c5bb8520)
    {
        $this->project = $project;
        $this->fields_rule_id = $_e7abfa820a3de22659425ae05962f998;
        $this->fields_rule_name = $_d6ae4fd435b96c98064a7e6e29911624;
        $this->timer_type = $_c81931b478b71965c9977c8cbb5f8da4;
        $this->old_rules = $_bf4b599ba97e569860bd6ef9aea99c33;
        $this->new_rules = $_af3a0d50187ba59bd7cde5c4c5bb8520;
    }
    
    
    
    
    public function getProject() : \HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getFieldsRuleId() : int
    {
        return $this->fields_rule_id;
    }
    
    
    
    
    public function getFieldsRuleName() : string
    {
        return $this->fields_rule_name;
    }
    
    
    
    
    public function getTimerType() : int
    {
        return $this->timer_type;
    }
    
    
    
    
    public function getOldRules()
    {
        return $this->old_rules;
    }
    
    
    
    
    public function getNewRules()
    {
        return $this->new_rules;
    }
}
